==> nextcloud-app-deck-1%3A1.13.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/deck/l10n/oc.js <==
OC.L10N.register(
    "deck",
    {
    "Personal" : "Personal",
    "copy" : "copiar",
    "Done" : "Done",
    "The file was uploaded" : "Lo fichièr es estat enviat",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Lo fichièr enviat despassa la directiva upload_max_filesize de php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Lo fichièr enviat despassa la directiva MAX_FILE_SIZE especificada dins lo formulari HTML",
    "The file was only partially uploaded" : "Lo fichièr es estat parcialament enviat",
    "No file was uploaded" : "Cap de fichièr pas enviat",
    "Missing a temporary folder" : "Dossièr temporari absent",
    "Could not write file to disk" : "Escritura impossibla al disc",
    "A PHP extension stopped the file upload" : "Una extension PHP a arrestat lo mandadís de fichièr",
    "Invalid date, date format must be YYYY-MM-DD" : "Invalida data, lo format de data deu èsser YYYY-MM-DD",
    "Cancel" : "Anullar",
    "File already exists" : "Lo fichièr existís ja",
    "Drop your files to upload" : "Depausatz los fichièrs d’enviar",
    "Open" : "Dobrir",
    "Completed" : "Acabat",
    "Details" : "Detalhs",
    "Sharing" : "Partiment",
    "Tags" : "Etiquetas",
    "Deleted items" : "Elements suprimits",
    "Activity" : "Activitat",
    "Deleted lists" : "Listas suprimidas",
    "Undo" : "Desfar",
    "(Group)" : "(Grop)",
    "Can edit" : "Can edit",
    "Can share" : "Can share",
    "Owner" : "Owner",
    "Delete" : "Suprimir",
    "Edit" : "Modificar",
    "Members" : "Membres",
    "Upload new files" : "Enviar fichièrs novèls",
    "Share from Files" : "Partejar a partir dels Fichièrs",
    "Download" : "Telecargar",
    "File to share" : "Fichièr de partejar",
    "Invalid path selected" : "Camin seleccionat invalid",
    "Comments" : "Comentaris",
    "Modified" : "Modificat",
    "Save" : "Salvar",
    "Cancel reply" : "Anullar la responsa",
    "Reply" : "Respondre",
    "Update" : "Metre a jorn",
    "Created:" : "Creat lo :",
    "Description" : "Descripcion",
    "seconds ago" : "fa qualques segondas",
    "Keyboard shortcuts" : "Acorchis de clavièr",
    "Keyboard shortcut" : "Acorchis de clavièr",
    "Search" : "Recercar",
    "Shared with you" : "Shared with you",
    "No notifications" : "Cap de notificacion",
    "An error occurred" : "Una error s’es producha",
    "Today" : "Uèi",
    "Tomorrow" : "Deman",
    "{stack} in {board}" : "{stack} dins {board}",
    "Create a new card" : "Crear una carta novèla",
    "Create card" : "Crear una carta",
    "Close" : "Tampar",
    "Tomorrow – {timeLocale}" : "Deman – {timeLocale}",
    "Create a card" : "Crear una carta",
    "Share" : "Partejar",
    "Next week" : "Setmana seguenta",
    "Next month" : "Mes seguent"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-app-deck-1%3A1.17.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/deck/l10n/oc.js <==
OC.L10N.register(
    "deck",
    {
    "The file was uploaded" : "Lo fichièr es estat enviat",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Lo fichièr enviat despassa la directiva upload_max_filesize de php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Lo fichièr enviat despassa la directiva MAX_FILE_SIZE especificada dins lo formulari HTML",
    "The file was only partially uploaded" : "Lo fichièr es estat parcialament enviat",
    "No file was uploaded" : "Cap de fichièr pas enviat",
    "Missing a temporary folder" : "Dossièr temporari absent",
    "Could not write file to disk" : "Escritura impossibla al disc",
    "A PHP extension stopped the file upload" : "Una extension PHP a arrestat lo mandadís de fichièr",
    "copy" : "copiar",
    "Done" : "Done",
    "File" : "Fichier",
    "Invalid date, date format must be YYYY-MM-DD" : "Invalida data, lo format de data deu èsser YYYY-MM-DD",
    "Cancel" : "Anullar",
    "Drop your files to upload" : "Depausatz los fichièrs d’enviar",
    "File already exists" : "Lo fichièr existís ja",
    "Open" : "Dobrir",
    "Completed" : "Acabat",
    "Details" : "Detalhs",
    "General" : "Generals",
    "Appearance" : "Aparéncia",
    "Search" : "Recercar",
    "Sharing" : "Partiment",
    "Tags" : "Etiquetas",
    "Deleted items" : "Elements suprimits",
    "Activity" : "Activitat",
    "Deleted lists" : "Listas suprimidas",
    "Undo" : "Desfar",
    "(Group)" : "(Grop)",
    "Can edit" : "Can edit",
    "Can share" : "Can share",
    "Owner" : "Owner",
    "Delete" : "Suprimir",
    "Edit" : "Modificar",
    "Members" : "Membres",
    "File to share" : "Fichièr de partejar",
    "Invalid path selected" : "Camin seleccionat invalid",
    "Upload new files" : "Enviar fichièrs novèls",
    "Share from Files" : "Partejar a partir dels Fichièrs",
    "Download" : "Telecargar",
    "Modified" : "Modificat",
    "Comments" : "Comentaris",
    "Created:" : "Creat lo :",
    "Cancel reply" : "Anullar la responsa",
    "Reply" : "Respondre",
    "Update" : "Metre a jorn",
    "Description" : "Descripcion",
    "Tomorrow – {timeLocale}" : "Deman – {timeLocale}",
    "Edit title" : "Modificar lo títol",
    "seconds ago" : "fa qualques segondas",
    "Shared with you" : "Shared with you",
    "Cancel edit" : "Anullar la modificacion",
    "An error occurred" : "Una error s’es producha",
    "No notifications" : "Cap de notificacion",
    "Advanced options" : "Opcions avançadas",
    "Export" : "Exportar",
    "{stack} in {board}" : "{stack} dins {board}",
    "Create card" : "Crear una carta",
    "Create a new card" : "Crear una carta novèla",
    "Close" : "Plegar",
    "Create a card" : "Crear una carta",
    "Share" : "Partejar",
    "Personal" : "Personal",
    "Save" : "Salvar",
    "Keyboard shortcuts" : "Acorchis de clavièr",
    "Keyboard shortcut" : "Acorchis de clavièr",
    "Today" : "Uèi",
    "Tomorrow" : "Deman"
},
"nplurals=2; plural=(n > 1);");
